================================
Newt DB, the amphibious database
================================

Python objects above, Postgtresql JSONB below.

See http://www.newtdb.org

Changes
=======

0.1.2 (2017-01-26)
==================

- Fixed a number of documentation errors.

  (Documentation wasn't tested, but now is, thankd to `manuel
  <http://pythonhosted.org/manuel/>`_.)

- Added some missing names to ``newt.db``.

0.1.1 (2017-01-24)
==================

Fixed a small Python 2 bug that prevented import.

0.1.0 (2017-01-24)
==================

Initial release
